SWDEV-331548 - fix test hang issue (#2658)

destroy stream before exit

Change-Id: I1a51ae349d0dd9a5ff6cdac21c5930bd6d87e021
Dieser Commit ist enthalten in:
ROCm CI Service Account
2022-05-05 11:55:50 +05:30
committet von GitHub
Ursprung afa1e43916
Commit b0f3b08ad8
2 geänderte Dateien mit 4 neuen und 2 gelöschten Zeilen
@@ -1,5 +1,5 @@
/*
Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
@@ -61,6 +61,7 @@ TEST_CASE("Unit_hipStreamCreate_MultistreamBasicFunctionalities") {
hipAPIStreamDisableTest::NN);
hipLaunchKernelGGL(HIP_KERNEL_NAME(hipAPIStreamDisableTest::nKernel),
dim3(1), dim3(1), 0, 0, yd);
HIP_CHECK(hipStreamDestroy(streams[i]));
}
HIP_CHECK(hipMemcpy(&x, xd, sizeof(float), hipMemcpyDeviceToHost));
HIP_CHECK(hipMemcpy(&y, yd, sizeof(float), hipMemcpyDeviceToHost));
+2 -1
Datei anzeigen
@@ -1,5 +1,5 @@
/*
Copyright (c) 2021 Advanced Micro Devices, Inc. All rights reserved.
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
@@ -51,6 +51,7 @@ TEST_CASE("Unit_hipMultiStream_sameDevice") {
hipLaunchKernelGGL(kernel, dim3(1), dim3(1), 0, streams[i], data[i], xd, NN);
hipLaunchKernelGGL(HIP_KERNEL_NAME(nKernel), dim3(1), dim3(1), 0, 0, yd);
HIP_CHECK(hipFree(data[i]));
HIP_CHECK(hipStreamDestroy(streams[i]));
}
HIP_CHECK(hipMemcpy(&x, xd, sizeof(float), hipMemcpyDeviceToHost));
HIP_CHECK(hipMemcpy(&y, yd, sizeof(float), hipMemcpyDeviceToHost));